package ru.myitschool.work.ui.main

import android.os.Bundle
import android.util.Log
import android.view.View
import androidx.fragment.app.Fragment
import androidx.lifecycle.lifecycleScope
import kotlinx.coroutines.launch
import ru.myitschool.work.R
import ru.myitschool.work.api.ApiService
import ru.myitschool.work.api.EmployeeData
import ru.myitschool.work.core.Constants
import ru.myitschool.work.databinding.FragmentMainBinding
import ru.myitschool.work.SessionManager
import retrofit2.Retrofit
import retrofit2.converter.gson.GsonConverterFactory

class MainFragment : Fragment(R.layout.fragment_main) {
    private var _binding: FragmentMainBinding? = null
    private val binding get() = _binding!!

    private lateinit var apiService: ApiService

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        apiService = Retrofit.Builder()
            .baseUrl(Constants.SERVER_ADDRESS)
            .addConverterFactory(GsonConverterFactory.create())
            .build()
            .create(ApiService::class.java)
    }

    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
        super.onViewCreated(view, savedInstanceState)
        _binding = FragmentMainBinding.bind(view)

        setupUI()
        fetchUserInfo()
    }

    private fun setupUI() {
        // Инициализация UI компонентов, если необходимо
        binding.refresh.setOnClickListener {
            fetchUserInfo()
        }
    }

    private fun fetchUserInfo() {
        lifecycleScope.launch {
            val login = SessionManager.userLogin ?: return@launch
            val authHeader = SessionManager.getAuthHeader() // Получаем заголовок авторизации

            Log.d("MainFragment", "Fetching user info for login: $login with authHeader: $authHeader")

            val response = apiService.getUserInfo(login, authHeader)

            Log.d("MainFragment", "Response code: ${response.code()}") // Логируем код ответа

            if (response.isSuccessful) {
                val employeeData = response.body()
                employeeData?.let {
                    binding.fullname.text = it.name
                    binding.position.text = it.position
                    binding.lastEntry.text = it.lastVisit
                    binding.photo.visibility = View.VISIBLE
                    binding.fullname.visibility = View.VISIBLE
                    binding.position.visibility = View.VISIBLE
                    binding.lastEntry.visibility = View.VISIBLE
                }
            } else {
                binding.error.text = "Ошибка получения данных: ${response.message()}"
                binding.error.visibility = View.VISIBLE
            }
        }
    }

    override fun onDestroyView() {
        _binding = null
        super.onDestroyView()
    }
}